<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Reviews Documentation

- **[development.md](development.md)** — creating a new code review for CI, adding a new review spec to .erk/reviews/, understanding the end-to-end review creation process
- **[test-coverage-agent.md](test-coverage-agent.md)** — modifying test-coverage review agent prompt, adding new legitimately untestable file patterns, debugging false positives in test coverage review
